Author: Maciej Fijalkowski <[email protected]>
Branch: jitframe-on-heap
Changeset: r62333:d736ec9b08e9
Date: 2013-03-13 17:42 -0700
http://bitbucket.org/pypy/pypy/changeset/d736ec9b08e9/

Log:    (arigo, alex, fijal) try to fix the alignment (how this could have
        worked)

diff --git a/rpython/jit/backend/x86/arch.py b/rpython/jit/backend/x86/arch.py
--- a/rpython/jit/backend/x86/arch.py
+++ b/rpython/jit/backend/x86/arch.py
@@ -30,9 +30,9 @@
 # start of every frame: the saved value of some registers
 
 if WORD == 4:
-    # ebp + ebx + esi + edi + 12 extra words + return address = 17 words
-    FRAME_FIXED_SIZE = 17
-    PASS_ON_MY_FRAME = 12
+    # ebp + ebx + esi + edi + 14 extra words + return address = 19 words
+    FRAME_FIXED_SIZE = 19
+    PASS_ON_MY_FRAME = 14
     JITFRAME_FIXED_SIZE = 6 + 8 * 2 # 6 GPR + 8 XMM * 2 WORDS/float
 else:
     # rbp + rbx + r12 + r13 + r14 + r15 + 12 extra words + return address = 19
_______________________________________________
pypy-commit mailing list
[email protected]
http://mail.python.org/mailman/listinfo/pypy-commit

Reply via email to